# REECO Python

Python library for the REECO framework.


## Schema

TBD

### Developers
Editing happens in this [Spreadsheet](https://docs.google.com/spreadsheets/d/1PZ11esT6COK7Y0mMZEHifY9hQeREbNSlRbC6dkYtjNg/edit?usp=sharing).

The reference documentation is in folder `schema/`.

To regenerate the `yaml` files in the schema directory:
```bash
python3 generate-schema.py && git add schema/ && git commit -m "Update" && git push
```

## Validator

TBD